/**********************************************************************
 
	Copyright (C) 2003-2004
	Hirohisa MORI <joshua@nichibun.ac.jp>
	Tomoki SEKIYAMA <sekiyama@yahoo.co.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/



#ifndef ___V_CHOOSE_FILE_H___
#define ___V_CHOOSE_FILE_H___

#ifdef __cplusplus
extern "C" {
#endif

#include "xl.h"
#include "long_char.h"

#define VCT_CHOOSE_FILE		1
#define VCT_SAVE_FILE		2

char *	v_choose_file(const L_CHAR *title = 0, const char *default_path = 0);
char *	v_save_as_file(const L_CHAR *title = 0, const char *default_path = 0);

void init_VChooseFile(XLISP_ENV *env);
void init_VSaveAsFile(XLISP_ENV *env);

#ifdef __cplusplus
}
#endif

#endif
